.. _pylatex:

Pylatex subclasses
==================

One very usefull way to interact with LaTeX using Python is the package `PyLaTeX <https://github.com/JelteF/PyLaTeX>`__ . DMT has already some of the necessary subclasses to make report writing easy implemented and ready to use:

.. automodule:: DMT.external.pylatex
    :members:
    :undoc-members:
    :show-inheritance: